@@ -12,6 +12,7 @@ from .functions import (
     drop_database,
     escape_like,
     get_bind,
+    get_column_key,
     get_columns,
     get_declarative_base,
     get_mapper,
@@ -32,6 +33,7 @@ from .functions import (
     table_name,
 )
 from .listeners import (
+    auto_delete_orphans,
     coercion_listener,
     force_auto_coercion,
     force_instant_defaults
@@ -68,13 +70,15 @@ from .types import (
     UUIDType,
     WeekDaysType
 )
+from .models import Timestamp
 
 
-__version__ = '0.26.3'
+__version__ = '0.26.5'
 
 
 __all__ = (
     aggregated,
+    auto_delete_orphans,
     batch_fetch,
     coercion_listener,
     create_database,
@@ -89,6 +93,7 @@ __all__ = (
     generates,
     generic_relationship,
     get_bind,
+    get_column_key,
     get_columns,
     get_declarative_base,
     get_mapper,
@@ -135,9 +140,10 @@ __all__ = (
     QueryChain,
     ScalarListException,
     ScalarListType,
+    Timestamp,
     TimezoneType,
     TSVectorType,
     URLType,
     UUIDType,
-    WeekDaysType
+    WeekDaysType,
 )
